CLI Types
=========

.. automodule:: oduit.cli_types
   :members:
   :undoc-members:
   :show-inheritance:

Enumerations
------------

.. autoclass:: oduit.cli_types.OutputFormat
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: oduit.cli_types.AddonTemplate
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: oduit.cli_types.AddonListType
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: oduit.cli_types.ShellInterface
   :members:
   :undoc-members:
   :show-inheritance:

Data Classes
------------

.. autoclass:: oduit.cli_types.GlobalConfig
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: oduit.cli_types.CommandResult
   :members:
   :undoc-members:
   :show-inheritance:
